<?php


namespace app\cbcrm\controller\customer;


use app\cbcrm\controller\BaseUser;
use app\cbcrm\model\manage\DepartmentModel;
use think\Request;

class Customer extends BaseUser
{
    protected $model = null;

    public function __construct(Request $request)
    {
        $this->model = (new \app\cbcrm\model\customer\CustomerModel());
        parent::__construct($request);
    }

    public function index()
    {
        $customer= \request()->get('customer','','strip_tags');
        $department_id = \request()->get('department_id',0,'intval');
        $where = [];
        if ($customer) {
            $where[] = ['customer_model.name|contacts.name','LIKE',"%{$customer}%"];
        }

        if ($department_id) {
            $staffIds = $this->getDepartmentStaffIds($department_id,$this->user['id'],false);
            $departmentParentId = (new DepartmentModel())->where('wid',$this->wid)->where('id',$department_id)->value('parent_id');
            if (!$departmentParentId && $this->user['isSuper']) {
                array_push($staffIds,$this->user['id']);
            }
            $where[] = ['customer_model.staff_id','IN',$staffIds];
        }else{
            if (!$this->user['isSuper']) {
                $where[] = ['customer_model.staff_id','IN',$this->getDepartmentStaffIds($this->user['department_id'],$this->user['id'],true)];
            }
        }
        $list = $this->model->getList($where,$this->wid);
        return success('返回成功', $list);
    }

    /*
     * 添加客户
     * */
    public function add()
    {
        $params = \request()->post('form');
        $params['is_super'] = 0;
        if ((!isset($params['staff_id']) || !$params['staff_id']) && $this->user['isSuper']) {
            $params['is_super'] = 1; // 不选择员工且当前用户为超管时，表示为超管录入
        }
        $params['staff_id'] = isset($params['staff_id']) && $params['staff_id']?$params['staff_id']:$this->user['id'];
        $result = $this->model->addCustomer($params, $this->wid,$params['staff_id']);
        if ($result === true) {
            return success('添加成功', $result);
        } else {
            return error($result);
        }
    }

    /*
     * 编辑客户
     * */
    public function edit()
    {
        $id = \request()->post('id', 0, 'intval');
        $params = \request()->post('form');
        $params['is_super'] = 0;
        if ((!isset($params['staff_id']) || !$params['staff_id']) && $this->user['isSuper']) {
            $params['is_super'] = 1; // 不选择员工且当前用户为超管时，表示为超管录入
        }
        $params['staff_id'] = isset($params['staff_id']) && $params['staff_id']?$params['staff_id']:$this->user['id'];
        $result = $this->model->editCustomer($id, $params, $this->wid);
        if ($result === true) {
            return success('编辑成功', $result);
        } else {
            return error($result);
        }
    }


    /*
     * 删除客户
     * */
    public function del()
    {
        $id = \request()->delete('id', 0, 'intval');
        $result = $this->model->delCustomer($id,$this->wid);
        if ($result === true) {
            return success('删除成功', $result);
        } else {
            return error($result);
        }
    }

    /*
     * 获取客户详情
     * */
    public function detail()
    {
        $id = \request()->get('id', 0, 'intval');

        $row = $this->model->getDetail($id, $this->wid);

        return success('返回成功', $row);
    }

    /*
     * 客户查重
     * */
    public function checkCustomer()
    {
        $id = \request()->get('id', 0, 'intval');
        $name = \request()->get('name');
        if (!$name) {
            return error('请输入客户名称');
        }
        $query = $this->model->where('name', 'LIKE', '%' . $name . '%')->where('wid', $this->wid);
        if ($id) {
            $query->where('id','<>',$id);
        }
        $list = $query->paginate(15);

        return success('返回成功', $list);
    }

    /*
     * 获取表单数据字典
     * */
    public function getFormData()
    {
        $data = $this->model->getFormData($this->wid);
        return success('返回成功', $data);
    }
}
