<?php


namespace app\cbcrm\controller\manage;


use app\cbcrm\controller\BaseUser;
use app\cbcrm\model\manage\DepartmentModel;
use app\cbcrm\model\manage\RoleModel;
use app\cbcrm\model\manage\StaffModel;
use think\facade\Db;
use think\Request;

class Staff extends BaseUser
{
    protected $model = null;

    public function __construct(Request $request)
    {
        parent::__construct($request);

        $this->model = new StaffModel();
    }

    public function index()
    {
        $username = request()->get('username','','strip_tags');
        $department_id = request()->get('department_id',0,'intval');
        $role_id = request()->get('role_id',0,'intval');
        $pageSize= request()->get('pageSize',15,'intval');
        $params[] = ['wid','=',$this->wid];
        if ($username) {
            $params[] = ['username|nickname|mobile','LIKE',"%{$username}%"];
        }
        if ($department_id) {
            $departmentList = (new DepartmentModel())->getList($this->wid);
            $departmentIds = getChildrenIds($department_id,$departmentList);
            array_push($departmentIds,$department_id);
            $params[] = ['department_id','IN',$departmentIds];
        }
        if ($role_id) {
            $roleList = (new RoleModel())->getList($this->wid);
            $roleIds = getChildrenIds($role_id,$roleList);
            array_push($roleIds,$role_id);
            $params[] = ['role_id','IN',$roleIds];
        }
        $list = $this->model->getList($params,$pageSize);

        return success('返回成功',$list);
    }

    public function add()
    {
        $params = \request()->post('form');
        $params['wid'] = $this->wid;

        $hasStaff = $this->model->where('username',$params['username'])->value('id');
        $hasUser = Db::table('kt_base_user')->where('un',$params['username'])->value('id');
        if ($hasStaff) {
            return error('登录帐号已在系统中存在');
        }
        if ($hasUser) {
            return error('登录帐号和系统帐号冲突');
        }

        $salt = random_build('alnum', 5);

        $new_password = ktEncrypt($params['password'],$salt);
        $params['password'] = $new_password;
        $params['salt'] = $salt;

        $result = $this->model->saveData($params);
        if ($result) {
            return success('添加成功');
        }else{
            return error('添加失败');
        }
    }

    public function edit()
    {
        $id = \request()->post('id',0,'intval');
        $params = \request()->post('form');
        $params['wid'] = $this->wid;
        $row = $this->model->where('id',$id)->find();
        if (!$row) {
            return error('内容未找到');
        }
        $hasStaff = $this->model->where('username',$params['username'])->where('id','<>',$row->id)->value('id');
        $hasUser = Db::table('kt_base_user')->where('un',$params['username'])->value('id');
        if ($hasStaff) {
            return error('登录帐号已在系统中存在');
        }
        if ($hasUser) {
            return error('登录帐号和系统帐号冲突');
        }
        if (isset($params['password']) && $params['password']) {
            $salt = random_build('alnum', 5);
            $new_password = ktEncrypt($params['password'],$salt);
            $params['password'] = $new_password;
            $params['salt'] = $salt;
        }else{
            unset($params['password']);
        }

        $result = $row->save($params);
        if ($result) {
            return success('编辑成功');
        }else{
            return error('编辑失败');
        }
    }

    public function del()
    {
        $id = \request()->delete('id',0,'intval');
        $row = $this->model->where('id',$id)->where('wid',$this->wid)->find();
        if (!$row) {
            return error('未找到该内容');
        }
        if ($row->id == $this->user['id'] && $this->user['is_staff']) {
            return error('不能删除自己');
        }
        $row->delete();
        return success('删除成功');
    }
}
